{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap-merge:v0.0.3"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--columns"
                    },
                    "doc": "Comma-separated list of column to be print in the output.\nDefault: all\n",
                    "id": "#feature-select-sql.cwl/columns"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--raw"
                    },
                    "doc": "Input CSV/TSV file to be filtered by SQL query\n",
                    "id": "#feature-select-sql.cwl/feature_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--header"
                    },
                    "doc": "Print header in the output.\nDefault: false\n",
                    "id": "#feature-select-sql.cwl/header"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--output"
                    },
                    "doc": "Filename for filtered output TSV file.\nDefault: rootname(feature_file)_filtered.tsv\n",
                    "id": "#feature-select-sql.cwl/output_filename"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--sql"
                    },
                    "doc": "SQL query parameters that will be appended to `SELECT *` statement\n",
                    "id": "#feature-select-sql.cwl/sql_query"
                }
            ],
            "baseCommand": [
                "sql_select.R"
            ],
            "stdout": "sql_select_stdout.log",
            "stderr": "sql_select_stderr.log",
            "label": "Feature select - filters TSV/CSV files based on the provided SQL query parameters",
            "doc": "Tool filters input TSV/CSV file based on the provided SQL query.\nValue set in sql_query parameter will be appended to the\n\"SELECT * FROM raw_data WHERE\". Column names in sql_query are case\ninsensitive. Format of the input files is identified based on file\nextension\n*.csv - CSV\n*.tsv - TSV\nOtherwise used CSV by default. Output is always saved in TSV format.\n",
            "id": "#feature-select-sql.cwl",
            "http://schema.org/name": "Feature select - filters TSV/CSV files based on the provided SQL query parameters",
            "http://schema.org/alternateName": "Feature select - filters TSV/CSV files based on the provided SQL query parameters",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/feature-select-sql.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "usage: sql_select.R [-h] -r RAW -s SQL [-o OUTPUT]\n\nFilter CSV/TSV file based on the provided SQL query\n\noptional arguments:\n  -h, --help            show this help message and exit\n  -r RAW, --raw RAW     Input CSV/TSV file\n  -s SQL, --sql SQL     SQL query parameters that will be appended to `SELECT\n                        *` statement\n  -o OUTPUT, --output OUTPUT\n                        Filename for filtered output TSV file\n",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename?inputs.output_filename:\"*_filtered.tsv\")"
                    },
                    "id": "#feature-select-sql.cwl/filtered_file"
                },
                {
                    "type": "File",
                    "id": "#feature-select-sql.cwl/stderr_log",
                    "outputBinding": {
                        "glob": "sql_select_stderr.log"
                    }
                },
                {
                    "type": "File",
                    "id": "#feature-select-sql.cwl/stdout_log",
                    "outputBinding": {
                        "glob": "sql_select_stdout.log"
                    }
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "sd:upstream": {
                "sample_to_filter": [
                    "chipseq-se.cwl",
                    "chipseq-pe.cwl",
                    "trim-chipseq-se.cwl",
                    "trim-chipseq-pe.cwl",
                    "trim-atacseq-se.cwl",
                    "trim-atacseq-pe.cwl"
                ]
            },
            "inputs": [
                {
                    "type": "string",
                    "label": "Experiment short name/Alias",
                    "sd:preview": {
                        "position": 1
                    },
                    "id": "#main/alias"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "default": [
                        "chrom",
                        "start",
                        "end",
                        "chrom || '-' || start || '-' || end AS name"
                    ],
                    "label": "Columns to print",
                    "doc": "List of columns to print (SELECT parameters for SQL query).\nNeed to have format [chrom start end name]. No header.\n4th columns should be unique, so we use a combination of chrom-start-end.\n",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/columns"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "label": "ChIP/ATAC experiment",
                    "doc": "Called peaks file in TSV format with the nearest genes assigned",
                    "sd:upstreamSource": "sample_to_filter/iaintersect_result",
                    "sd:localLabel": true,
                    "id": "#main/feature_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "label": "Include header line",
                    "doc": "Print header line in the output file",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/header"
                },
                {
                    "type": "string",
                    "label": "Filtering parameters",
                    "doc": "Filtering parameters (WHERE parameters for SQL query)",
                    "sd:filtering": {
                        "params": {
                            "columns": [
                                "refseq_id",
                                "gene_id",
                                "txStart",
                                "txEnd",
                                "strand",
                                "chrom",
                                "start",
                                "end",
                                "length",
                                "abssummit",
                                "pileup",
                                "log10p",
                                "foldenrich",
                                "log10q",
                                "region"
                            ],
                            "types": [
                                "string",
                                "string",
                                "number",
                                "number",
                                "string",
                                "string",
                                "number",
                                "number",
                                "number",
                                "number",
                                "number",
                                "number",
                                "number",
                                "number",
                                "string"
                            ]
                        }
                    },
                    "id": "#main/sql_query"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3003",
                    "label": "Filtered called peaks with the nearest genes assigned",
                    "doc": "Regions of interest formatted as headerless BED file with [chrom start end name]",
                    "outputSource": "#main/feature_select/filtered_file",
                    "sd:visualPlugins": [
                        {
                            "syncfusiongrid": {
                                "tab": "Filtering results",
                                "Title": "Filtered table"
                            }
                        }
                    ],
                    "id": "#main/filtered_file"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2330",
                    "label": "Filtering stderr log",
                    "doc": "Filtering stderr log",
                    "outputSource": "#main/feature_select/stderr_log",
                    "id": "#main/filtering_stderr_log"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2330",
                    "label": "Filtering stdout log",
                    "doc": "Filtering stdout log",
                    "outputSource": "#main/feature_select/stdout_log",
                    "id": "#main/filtering_stdout_log"
                }
            ],
            "steps": [
                {
                    "run": "#feature-select-sql.cwl",
                    "in": [
                        {
                            "source": "#main/columns",
                            "valueFrom": "$(\"DISTINCT \" + self.join(\", \"))",
                            "id": "#main/feature_select/columns"
                        },
                        {
                            "source": "#main/feature_file",
                            "id": "#main/feature_select/feature_file"
                        },
                        {
                            "source": "#main/header",
                            "id": "#main/feature_select/header"
                        },
                        {
                            "source": "#main/sql_query",
                            "id": "#main/feature_select/sql_query"
                        }
                    ],
                    "out": [
                        "#main/feature_select/filtered_file",
                        "#main/feature_select/stdout_log",
                        "#main/feature_select/stderr_log"
                    ],
                    "id": "#main/feature_select"
                }
            ],
            "label": "Filter ChIP/ATAC peaks for Tag Density Profile or Motif Enrichment analyses",
            "doc": "Filters ChIP/ATAC peaks with the neatest genes assigned for Tag Density Profile or Motif Enrichment analyses\n============================================================================================================\n\nTool filters output from any ChIP/ATAC pipeline to create a file with regions of interest for Tag Density\nProfile or Motif Enrichment analyses. Peaks with duplicated coordinates are discarded.\n",
            "id": "#main",
            "http://schema.org/name": "Filter ChIP/ATAC peaks for Tag Density Profile or Motif Enrichment analyses",
            "http://schema.org/alternateName": "Filter ChIP/ATAC peaks for Tag Density Profile or Motif Enrichment analyses",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/datirium/workflows/master/workflows/filter-peaks-for-heatmap.cwl",
            "http://schema.org/codeRepository": "https://github.com/datirium/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://github.com/schemaorg/schemaorg/raw/main/data/releases/11.01/schemaorg-current-http.rdf"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
